This directory contains IPython Notebooks (http://ipython.org/notebook.html)
with a selection of Orange tutorials.

The current list includes:
* [Custom learners in Orange](https://github.com/biolab/orange3/blob/master/tutorials/learners.ipynb)
